#if !defined(SYSTEM_H)
#define SYSTEM_H TRUE
/* ========================================================================
 * Name - system.h
 *
 * Description - isolate system dependencies
 *
 * $Id: system.h,v 1.3 1992/09/16 22:35:08 penneyj Exp $
 *
 * $Log: system.h,v $
 * Revision 1.3  1992/09/16  22:35:08  penneyj
 * clarify conditional compiles
 *
 * Revision 1.2  1992/09/15  22:37:40  penneyj
 * misc facelift, preparing for distribution on alt.sources
 *
 * Revision 1.1  1992/09/15  22:18:47  penneyj
 * Initial revision
 *
 *========================================================================
 */

/* First of all, pick a cpp flag to define your system...
 *
 * Currently in use:
 *
 * _AIX -- IBM RS/6000, running AIX 3.2
 * __hpux -- HP9000/700 PA-RISC, running hpux
 * _SEQUENT_ -- Sequent Symmetry
 * sparc -- Sun-4, running SunOS 4.1.2
 * ultrix -- DEC Ultrix
 *
 */

/* Second of all, define flags for your operating system and compiler */
#if defined(_AIX)
#define FLG_AIX_UNIX TRUE
#define FLG_AIXC TRUE
#endif

#if defined(__hpux)
#define FLG_HPUX_UNIX TRUE
#define FLG_HPUXC TRUE
#endif

#if defined(_SEQUENT_)
#define FLG_SEQUENT_UNIX TRUE

#if defined(__STDC__)
#define FLG_SEQUENT_ACC TRUE
#else
#define FLG_SEQUENTC TRUE /* not further used or tested! */
#endif

#endif /* _SEQUENT_ */

#if defined(sparc)
#define FLG_SUN_UNIX TRUE

#if !defined(__GNUC__)
#define FLG_SUNC TRUE
#endif

#endif /* sparc */

#if defined(ultrix)
#define FLG_ULTRIX_UNIX TRUE
#define FLG_ULTRIXC TRUE
#endif

/* gnuc -- special case */
#if defined(__GNUC__)
#define FLG_GNUC TRUE
#endif


/* Third of all, define properties based on your OS and compiler: */

/* FLG_PROTOTYPE -- define if your system supports function prototypes... */
#if defined(FLG_AIXC) || defined(FLG_HPUXC) || defined(FLG_SEQUENT_ACC)
#define FLG_PROTOTYPE TRUE
#endif
#if defined(FLG_GNUC)
#define FLG_PROTOTYPE TRUE
#endif

/* FLG_HAS_STDLIB_H -- define if your system has stdlib.h */
#if defined(FLG_AIX_UNIX) || defined(FLG_HPUX_UNIX) || defined(FLG_SEQUENT_UNIX)
#define FLG_HAS_STDLIB_H TRUE
#endif
#if defined(FLG_SUN_UNIX) || defined(FLG_ULTRIX_UNIX)
#define FLG_HAS_STDLIB_H TRUE
#endif

/* FLG_NO_STRCHR -- define if your system uses index and rindex, instead */
#if defined(FLG_SUN_UNIX) && !defined(FLG_GNUC)
#define FLG_NO_STRCHR
#endif

/* FLG_HAS_DIRECT -- define if readdir() returns a direct instead of a
   dirent */

/* FLG_HAS_MEMORY_H -- define if your system has memory.h */
#if defined(FLG_SUN_UNIX)
#define FLG_HAS_MEMORY_H TRUE
#endif

/* FLG_USE_WAIT3 -- define if your system needs wait3 instead of waitpid() */

/* FLG_NO_MEMMOVE -- define if your system has no memmove call */
#if defined(FLG_SUN_UNIX)
#define FLG_NO_MEMMOVE TRUE
#endif

/* FLG_NO_BCOPY -- define if your system has no bcopy call AND no memmove. */

/* FLG_NO_CONST -- define if your compiler doesn't dig "const" */
#if defined(FLG_SUNC)
#define FLG_NO_CONST
#endif
#if defined(FLG_ULTRIXC)
#define FLG_NO_CONST
#endif

/* now we do all the nasty work... */

#include <stdio.h>
#include <signal.h>
#include <errno.h>
#include <ctype.h>

#if defined(FLG_HAS_STDLIB_H)
#include <stdlib.h>
#endif

#if defined(FLG_PROTOTYPE)
#include <stdarg.h>
#else
#include <varargs.h>
#endif

#if defined(FLG_NO_STRCHR)
#define strchr index
#define strrchr rindex
#endif

#if defined(FLG_SEQUENT_UNIX) || defined(FLG_HPUX_UNIX)
#include <string.h>
#else
#include <strings.h>
#endif

#include <unistd.h>
#include <sys/types.h>

#if defined(FLG_HAS_DIRECT)
#include <sys/dir.h>
typedef struct direct DirectoryEntrySType;
#else
#include <dirent.h>
typedef struct dirent DirectoryEntrySType;
#endif

#include <sys/time.h>

#include <sys/stat.h>    /* Neccesary for stat            */
#include <sys/file.h>    /* To define R_OK used by access */

#include <sys/resource.h>
#include <sys/wait.h>

#if defined(FLG_USE_WAIT3)
#define DOWAIT wait3(0, WNOHANG, 0)
#else
#define DOWAIT waitpid(-1, 0, WNOHANG)
#endif

#if defined(FLG_NO_MEMMOVE)
#if defined(FLG_NO_BCOPY)
+++ panic, memmove not implemented here
#else
#define memmove(dest, src, len) bcopy(src, dest, len)

#if defined(FLG_PROTOTYPE)
void bcopy(const void *src, void *dest, int len);
#else
void bcopy();
#endif

#endif /* FLG_NO_BCOPY */
#endif /* FLG_NO_MEMMOVE */

#if defined(FLG_NO_CONST)
#define const
#endif

#if defined(FLG_HAS_MEMORY_H)
#include <memory.h>
#else

#if defined(FLG_PROTOTYPE)
void *malloc(size_t size);
#else
void *malloc();
#endif

#endif /* FLG_HAS_MEMORY_H */

#if defined(FLG_HPUX_UNIX) || defined(FLG_ULTRIX_UNIX) || (defined(FLG_SUN_UNIX) && !defined(FLG_GNUC))
  extern char *optarg;
  extern int optind;
  extern int opterr;
#endif

#if !defined(FLG_SEQUENT_UNIX) && !defined(FLG_HPUX_UNIX)
#if defined(FLG_PROTOTYPE)
int fork(void);
#else
int fork();
#endif
#endif

#if defined(FLG_PROTOTYPE)
char *getenv(const char name[]);
#else
char *getenv();
#endif

#if !defined(FLG_SEQUENT_UNIX) && !defined(FLG_HPUX_UNIX)
#if defined(FLG_PROTOTYPE)
int getpid(void);
#else
int getpid();
#endif
#endif

#if defined(FLG_PROTOTYPE)
int rename(const char from[], const char to[]);
#else
int rename();
#endif

#if (defined(FLG_SUN_UNIX) && defined(FLG_GNUC))
#if defined(FLG_PROTOTYPE)
int umask(int mask);
#else
int umask();
#endif
#endif /* if 0 */

#if defined(FLG_PROTOTYPE)
int unlink(const char fname[]);
#else
int unlink();
#endif

#if !defined(FLG_SEQUENT_UNIX) && !defined(FLG_HPUX_UNIX)
#if defined(FLG_PROTOTYPE)
int waitpid(int pid, int *statusp, int options);
#else
int waitpid();
#endif
#endif

#endif /* SYSTEM_H */
